Improve this Doc View Source

Provides read/write access to browser's cookies.

Up until Angular 1.3, `$cookies` exposed properties that represented the current browser cookie values. In version 1.4, this behavior has changed, and `$cookies` now provides a standard api of getters, setters etc.

Requires the `ngCookies` module to be installed.

## Methods

- ###

  `get(key);`

  Returns the value of given cookie key

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  key | string | Id to use for lookup.

  #### Returns

  string | Raw cookie value.

- ###

  `getObject(key);`

  Returns the deserialized value of given cookie key

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  key | string | Id to use for lookup.

  #### Returns

  Object | Deserialized cookie value.

- ###

  `getAll();`

  Returns a key value object with all the cookies

  #### Returns

  Object | All cookies

- ###

  `put(key, value, [options]);`

  Sets a value for given cookie key

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  key | string | Id for the `value`.
  value | string | Raw value to be stored.
  options (optional) | Object | Options object. See $cookiesProvider.defaults

- ###

  `putObject(key, value, [options]);`

  Serializes and sets a value for given cookie key

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  key | string | Id for the `value`.
  value | Object | Value to be stored.
  options (optional) | Object | Options object. See $cookiesProvider.defaults

- ###

  `remove(key, [options]);`

  Remove given cookie

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  key | string | Id of the key-value pair to delete.
  options (optional) | Object | Options object. See $cookiesProvider.defaults

## Examples

    angular.module('cookiesExample', ['ngCookies'])
    .controller('ExampleController', ['$cookies', function($cookies) {
      // Retrieving a cookie
      var favoriteCookie = $cookies.get('myFavorite');
      // Setting a cookie
      $cookies.put('myFavorite', 'oatmeal');
    }]);